@@ -576,8 +576,8 @@ add_proc_object_acl(struct proc_acl *subject, char *filename,
 	file_len++;
 
 	num_objects++;
-	/* one for the object, one for the filename, one for the name entry struct in the kernel*/
-	num_pointers += 3;
+	/* one for the object, one for the filename, one for the name entry struct, and one for the inodev_entry struct in the kernel*/
+	num_pointers += 4;
 
 	if (lstat(filename, &fstat)) {
 		dfile = add_deleted_file(filename);
@@ -788,16 +788,8 @@ role_mode_conv(const char *mode)
 		}
 	}
 
-	if (
-	    ((retmode & (GR_ROLE_NOPW | GR_ROLE_AUTH | GR_ROLE_PAM)) ==
-	    (GR_ROLE_NOPW | GR_ROLE_AUTH | GR_ROLE_PAM)) ||
-	    ((retmode & (GR_ROLE_NOPW | GR_ROLE_AUTH | GR_ROLE_PAM)) ==
-	     (GR_ROLE_NOPW | GR_ROLE_AUTH)) ||
-	    ((retmode & (GR_ROLE_NOPW | GR_ROLE_AUTH | GR_ROLE_PAM)) ==
-	     (GR_ROLE_AUTH | GR_ROLE_PAM)) ||
-	    ((retmode & (GR_ROLE_NOPW | GR_ROLE_AUTH | GR_ROLE_PAM)) ==
-	     (GR_ROLE_NOPW | GR_ROLE_PAM))) {
-		fprintf(stderr, "Error on line %lu of %s.  The role mode must contain only one of the auth, noauth, and pamauth modes.\n", lineno, current_acl_file);
+	if ((retmode & (GR_ROLE_NOPW | GR_ROLE_PAM)) == (GR_ROLE_NOPW | GR_ROLE_PAM)) {
+		fprintf(stderr, "Error on line %lu of %s.  The role mode must contain only one of the noauth and pamauth modes.\n", lineno, current_acl_file);
 		exit(EXIT_FAILURE);
 	}
 
